!-
MODULE constantes_co2
!---------------------------------------------------------------------
  USE reqdprec
  USE constantes
  USE constantes_veg
!-
  IMPLICIT NONE
!-
! indices for assimilation parameters
!-
  INTEGER(long),PARAMETER :: itmin = 1
  INTEGER(long),PARAMETER :: itopt = 2
  INTEGER(long),PARAMETER :: itmax = 3
  INTEGER(long),PARAMETER :: ivcmax = 4
  INTEGER(long),PARAMETER :: ivjmax = 5
  INTEGER(long),PARAMETER :: npco2 = 5
!-
! duplicate initialization to keep a trace
! in HTML auto generated file with f90doc
!!
!! The following tables of parameters for SECHIBA
!! are in the following order :
!!
!!    1 - Bare soil
!!    2 - tropical  broad-leaved evergreen
!!    3 - tropical  broad-leaved raingreen
!!    4 - temperate needleleaf   evergreen
!!    5 - temperate broad-leaved evergreen
!!    6 - temperate broad-leaved summergreen
!!    7 - boreal    needleleaf   evergreen
!!    8 - boreal    broad-leaved summergreen
!!    9 - boreal    needleleaf   summergreen
!!   10 -           C3           grass
!!   11 -           C4           grass
!!   12 -           C3           agriculture
!!   13 -           C4           agriculture
!!
!! flag for C4 vegetation types
!! is_c4 = .false.,.false.,.false.,.false.,.false.,.false.,
!!         .false.,.false.,.false.,.false.,.true.,.false.,.true.
  LOGICAL,DIMENSION(nvm),SAVE :: &
 &  is_c4 = (/.false.,.false.,.false.,.false.,.false.,.false., &
 &            .false.,.false.,.false.,.false.,.true.,.false.,.true. /)
!! Slope of the gs/A relation (Ball & al.)
!! gsslope = 0., 9., 9., 9., 9., 9., 9., 9., 9., 9., 3., 9., 3.
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  gsslope = (/0., 9., 9., 9., 9., 9., 9., 9., 9., 9., 3., 9., 3./)
!! intercept of the gs/A relation (Ball & al.)
!! gsoffset = 0.0,  0.01, 0.01, 0.01, 0.01, 0.01,
!!            0.01, 0.01, 0.01, 0.01, 0.03, 0.01, 0.03
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  gsoffset = (/0.0,  0.01, 0.01, 0.01, 0.01, 0.01, &
 &               0.01, 0.01, 0.01, 0.01, 0.03, 0.01, 0.03/)
!! values used for vcmax when STOMATE is not activated
!! vcmax_fix =  0., 40., 50., 30., 35., 40.,
!!             30., 40., 35., 60., 60., 70., 70.
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  vcmax_fix = (/  0., 40., 50., 30., 35., 40., &
 &                 30., 40., 35., 60., 60., 70., 70. /)
!! values used for vjmax when STOMATE is not activated
!! vjmax_fix =   0.,  80., 100.,  60.,  70.,  80.,
!!              60.,  80.,  70., 120., 120., 140., 140.
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  vjmax_fix = (/ 0., 80., 100., 60., 70., 80., &
 &                 60., 80., 70., 120., 120., 140., 140. /)
!! values used for photosynthesis tmin when STOMATE is not activated
!! co2_tmin_fix = 0.,  2.,  2., -4., -3., -2.,
!!               -4., -4., -4., -5.,  6., -5.,  6.
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  co2_tmin_fix = (/ 0.,  2.,  2., -4., -3., -2., &
 &                   -4., -4., -4., -5.,  6., -5.,  6. /)
!! values used for photosynthesis topt when STOMATE is not activated
!! co2_topt_fix = 0., 27.5, 27.5, 17.5, 25., 20.,
!!                 17.5, 17.5, 17.5, 20., 32.5, 20., 32.5
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  co2_topt_fix = (/  0.,  27.5, 27.5, 17.5, 25.,  20.,  &
 &                    17.5, 17.5, 17.5, 20.,  32.5, 20.,  32.5 /)
!! values used for photosynthesis tmax when STOMATE is not activated
!! co2_tmax_fix = 0., 55., 55., 38., 48., 38.,
!!               38., 38., 38., 45., 55., 45., 55.
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  co2_tmax_fix = (/ 0., 55., 55., 38., 48., 38., &
 &                   38., 38., 38., 45., 55., 45., 55. /)
!! extinction coefficient of the Monsi&Seaki relationship (1953)
!! ext_coef = .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5
  REAL(stnd),DIMENSION(nvm),SAVE :: &
 &  ext_coef = (/.5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5, .5/)
!! NV080800 Name of STOMATE forcing file
  CHARACTER(LEN=100) :: stomate_forcing_name='stomate_forcing.nc'
!! NV080800 Name of soil forcing file
  CHARACTER(LEN=100) :: stomate_Cforcing_name='stomate_Cforcing.nc'
!-
  INTEGER,SAVE :: forcing_id
!------------------------
END MODULE constantes_co2
